@@ -34,4 +34,5 @@ int Want_Screen_Resize;
 int Retro;
 /* Don't use high bit line drawing chars. */
 int Lowbit;
-
+/* Don't use 2 or 8 for up and down if set */
+int Numeric;
