@@ -66,6 +66,7 @@ Menu_Type *GetConfig (int argc, char **argv) {
     {PARAM_LONG_MENU,1,NULL,PARAM_SHORT_MENU},
     {PARAM_LONG_RETRO,0,NULL,PARAM_SHORT_RETRO},
     {PARAM_LONG_LOWBIT,0,NULL,PARAM_SHORT_LOWBIT},
+		{PARAM_LONG_NUMERIC,0,NULL,PARAM_SHORT_NUMERIC},
     {0, 0, 0, 0}
   };
 #endif
@@ -104,6 +105,13 @@ Menu_Type *GetConfig (int argc, char **argv) {
     case PARAM_SHORT_LOWBIT:
       Lowbit=1;
       break;
+		case PARAM_SHORT_NUMERIC:
+			/*
+			 * Override the default values for up and down, so 2 and 8 
+			 * can be used for hotkeys instead. 
+			 */
+			Numeric=1;
+			break;
     }
   }
 #else
