@@ -35,7 +35,8 @@ Usage: pdmenu [options] [menufiles ..]\n\
 \t-mmenuid  --menu=menuid   display menu with this menuid on startup\n\
 \t-v        --version       show version information\n\
 \t-r        --retro         draw menus using old style\n\
-\t-l        --lowbit        do not use high bit line drawing characters\n"
+\t-l        --lowbit        do not use high bit line drawing characters\n\
+\t-n        --numeric       do not use 8 and 2 for moving up and down\n"
 
 /* 
  * Parameters that can be passed to the program, both long and short 
@@ -57,13 +58,15 @@ Usage: pdmenu [options] [menufiles ..]\n\
 #define PARAM_SHORT_RETRO 'r'
 #define PARAM_LONG_LOWBIT "lowbit"
 #define PARAM_SHORT_LOWBIT 'l'
+#define PARAM_LONG_NUMERIC "numeric"
+#define PARAM_SHORT_NUMERIC 'n'
 
 /*
  * List here all the short options as one string 
  * this is formated for getopt, there should be colons after all options that
  * take parameters 
  */
-#define PARAM_SHORT_ALL "hcquvm:rl"
+#define PARAM_SHORT_ALL "hcquvm:rln"
 
 /*
  * Line that is displayed after the usage help if long options are 
